@@ -1,4 +1,4 @@
-# Copyright 2020 John Reese
+# Copyright 2022 Amethyst Reese
 # Licensed under the MIT license
 
 """
@@ -9,4 +9,4 @@ from .__version__ import __version__
 from .project import Project
 from .tag import Tag
 
-__author__ = "John Reese"
+__author__ = "Amethyst Reese"
