@@ -87,6 +87,7 @@ def debug() -> None:
         pprint = click.echo
 
     project = Project.load()
+    project.tags
     pprint(f"pyproject.toml: {project.pyproject_path()}")
     pprint(project)
 
@@ -101,9 +102,10 @@ def show_log() -> None:
     else:
         log_cmd = ["git", "log", "--reverse"]
 
-    log_cmd += ["--invert-grep"]
-    for author in project.config["ignored_authors"]:
-        log_cmd += [f"--author={author}"]
+    if project.config["ignored_authors"]:
+        log_cmd += ["--invert-grep"]
+        for author in project.config["ignored_authors"]:
+            log_cmd += [f"--author={author}"]
     sh(*log_cmd, raw=True)
 
 
@@ -142,9 +144,11 @@ def tag_release(version: Version, message: Optional[str]) -> None:
 
         if project.tags:
             tag = project.tags[0]
-            log_cmd = ["git", "log", "--reverse", f"{tag.name}..", "--invert-grep"]
-            for author in project.config["ignored_authors"]:
-                log_cmd += [f"--author={author}"]
+            log_cmd = ["git", "log", "--reverse", f"{tag.name}.."]
+            if project.config["ignored_authors"]:
+                log_cmd += ["--invert-grep"]
+                for author in project.config["ignored_authors"]:
+                    log_cmd += [f"--author={author}"]
             git_log = sh(*log_cmd)
             tpl += f"#\n# Changes since {tag.name}:\n#\n"
             tpl += "".join(f"# {line}\n" for line in git_log.splitlines(keepends=False))
